@@ -24,4 +24,6 @@ from expressions.constants import Constant
 from problems.problem import Problem
 from problems.objective import Maximize, Minimize
 import interface.numpy_wrapper
-from settings import CVXOPT, ECOS, OPTIMAL, UNBOUNDED, INFEASIBLE, SOLVER_ERROR
+from settings import (CVXOPT, ECOS, SCS,
+OPTIMAL, UNBOUNDED, INFEASIBLE, SOLVER_ERROR)
+
