@@ -107,22 +107,12 @@ class log_det(Atom):
         X = lu.create_var((2*n, 2*n))
         Z = lu.create_var((n, n))
         D = lu.create_var((n, n))
-        # Require that X is symmetric (which implies
-        # A is symmetric).
-        # X == X.T
-        obj, constraints = transpose.graph_implementation([X], (n, n))
-        constraints.append(lu.create_eq(X, obj))
         # Require that X and A are PSD.
-        constraints += [SDP(X), SDP(A)]
+        constraints = [SDP(X), SDP(A)]
         # Fix Z as upper triangular, D as diagonal,
         # and diag(D) as diag(Z).
         for i in xrange(n):
             for j in xrange(n):
-                if i == j:
-                    # D[i, j] == Z[i, j]
-                    Dij = index.get_index(D, constraints, i, j)
-                    Zij = index.get_index(Z, constraints, i, j)
-                    constraints.append(lu.create_eq(Dij, Zij))
                 if i != j:
                     # D[i, j] == 0
                     Dij = index.get_index(D, constraints, i, j)
@@ -131,6 +121,8 @@ class log_det(Atom):
                     # Z[i, j] == 0
                     Zij = index.get_index(Z, constraints, i, j)
                     constraints.append(lu.create_eq(Zij))
+        # D[i, i] = Z[i, i]
+        constraints.append(lu.create_eq(lu.diag_mat(D), lu.diag_mat(Z)))
         # Fix X using the fact that A must be affine by the DCP rules.
         # X[0:n, 0:n] == D
         index.block_eq(X, D, constraints, 0, n, 0, n)
