@@ -17,6 +17,7 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+import cvxpy.settings as s
 import cvxpy.lin_ops.lin_utils as lu
 from cvxpy.constraints.constraint import Constraint
 
@@ -37,11 +38,27 @@ class SDP(Constraint):
     def __str__(self):
         return "SDP(%s)" % self.A
 
-    def format(self):
+    def format(self, eq_constr, leq_constr, dims, solver):
         """Formats SDP constraints as inequalities for the solver.
+
+        Parameters
+        ----------
+        eq_constr : list
+            A list of the equality constraints in the canonical problem.
+        leq_constr : list
+            A list of the inequality constraints in the canonical problem.
+        dims : dict
+            A dict with the dimensions of the conic constraints.
+        solver : str
+            The solver being called.
         """
+        # A == A.T
+        eq_constr.append(lu.create_eq(self.A, lu.transpose(self.A)))
         # 0 <= A
-        return [lu.create_geq(self.A)]
+        leq_constr.append(lu.create_geq(self.A))
+        # Update dims.
+        dims[s.EQ_DIM] += self.size[0]*self.size[1]
+        dims[s.SDP_DIM].append(self.size[0])
 
     @property
     def size(self):
