@@ -17,8 +17,6 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from cvxpy.utilities.error import Error
-
 class Sign(object):
     """Sign of convex optimization expressions.
 
@@ -38,7 +36,7 @@ class Sign(object):
         if sign_str in Sign.SIGN_STRINGS:
             self.sign_str = sign_str
         else:
-            raise Error("'%s' is not a valid sign name." % str(sign_str))
+            raise ValueError("'%s' is not a valid sign name." % str(sign_str))
 
     @staticmethod
     def val_to_sign(val):
